@@ -5,7 +5,7 @@ from SAPOFTO import SAPOFTO
 
 def schedule(args):
     session_archetype = input('Please input the session type for this session:')
-    skeleton = SAPOFTO(key='SKELETON',filename='sessionskeletons.org')
+    skeleton = SAPOFTO.SAPOFTO(key='SKELETON',filename='sessionskeletons.org')
     roles_node = skeleton[session_archetype]['SUBJECT ROLES']
     for role_name in roles_node.key():
         subject_id = input('Please enter a user ID to fill the role of ' + role_name + ' for this session:')
@@ -15,9 +15,9 @@ def schedule(args):
             role_nodes[role_name].setValue('?????')
     schedule_org = None
     if os.path.isfile('session_schedule.org'):
-        schedule_org = SAPOFTO('SCHEDULE',filename='session_schedule.org')
+        schedule_org = SAPOFTO.SAPOFTO('SCHEDULE',filename='session_schedule.org')
     else:
-        schedule_org = SAPOFTO('SCHEDULE')
+        schedule_org = SAPOFTO.SAPOFTO('SCHEDULE')
     session_id = input('Please input the session\'s ID, or press enter to autogenerate a new ID...')
     if session_id == '':
         session_files = os.listdir('sessions/' + session_archetype)
@@ -38,7 +38,7 @@ def schedule(args):
             preceding_zeroes += '0'
         session_id = preceding_zeroes + str(new_id)
     session_key = 'TODO ' + session_archetype + str(session_id)
-    schedule_org.addChild(SAPOFTO(key=session_key))
+    schedule_org.addChild(SAPOFTO.SAPOFTO(key=session_key))
     schedule_org[session_key].addChild(roles_node)
     schedule_org.promote(1)
     
